@@ -1,7 +1,7 @@
 import inspect
 import logging
 import pathlib
-from collections import Callable
+from typing import Callable
 
 from lightning_fast.tools.logging_tools import LoggerUtil
 from lightning_fast.tools.meta_tools import SingletonMeta
